Installation
============

sugar.py requires Python 2.7 or 3.3+.

To install from `PyPI <https://pypi.python.org/pypi/sugar.py>`_:

::

    pip install sugar.py


You can also install sugar.py with all the latest changes:

::

    $ git clone git@github.com:bharadwajyarlagadda/sugar.py.git
    $ cd sugar.py
    $ python setup.py install

